@@ -6,7 +6,7 @@ owlobjects
 
 :Description: owlobjects
 
-    Classes for different owl objects
+    Classes for representing owl objects
 
 :Authors:
     bejar
@@ -23,6 +23,7 @@ datatypes = {XSD.string: 'STRING',
              XSD.integer: 'INTEGER',
              XSD.int: 'INTEGER',
              XSD.float: 'FLOAT',
+             XSD.decimal: 'FLOAT',
              XSD.double: 'FLOAT'}
 
 
@@ -136,6 +137,7 @@ class owlprop(owlobject):
     class for OWL properties
     """
     functional = False
+
     def __init__(self, uriref):
         """
         Initialize the class
@@ -192,7 +194,6 @@ class owlinstance(owlobject):
         :param cdict:
         :return:
         """
-
         iclass = graph.objects(self.uriref, RDF.type)
         # Selects the class for the instance skipping OWL.NamedIndividual
         for c in iclass:
@@ -218,7 +219,7 @@ class owlinstance(owlobject):
 
     def toCLIPS(self):
         """
-        Generate the CLIPS representation for an instacd
+        Generate the CLIPS representation for an instace
         :return:
         """
         level = '    '
@@ -233,7 +234,7 @@ class owlinstance(owlobject):
                 if isinstance(val, URIRef):
                     pr += f' [{self.chop(val)}]'
                 if isinstance(val, Literal):
-                    if val.datatype in [XSD.integer, XSD.int, XSD.float, XSD.double]:
+                    if val.datatype in [XSD.integer, XSD.int, XSD.float, XSD.double, XSD.decimal]:
                         pr += f' {val}'
                     else:
                         pr += f' "{val}"'
